package sun.management.snmp.jvmmib;

import javax.management.MBeanServer;
import com.sun.jmx.snmp.agent.SnmpMibTable;
import com.sun.jmx.snmp.agent.SnmpMibSubRequest;
import com.sun.jmx.snmp.SnmpGauge;
import com.sun.jmx.snmp.SnmpInt;
import com.sun.jmx.snmp.SnmpCounter64;
import com.sun.jmx.snmp.SnmpStatusException;
import com.sun.jmx.snmp.SnmpValue;
import com.sun.jmx.snmp.agent.SnmpMib;
import com.sun.jmx.snmp.agent.SnmpStandardObjectServer;
import com.sun.jmx.snmp.agent.SnmpStandardMetaServer;
import java.io.Serializable;
import com.sun.jmx.snmp.agent.SnmpMibGroup;

public class JvmMemoryMeta extends SnmpMibGroup implements Serializable, SnmpStandardMetaServer
{
    private static final long serialVersionUID = 9047644262627149214L;
    protected JvmMemoryMBean node;
    protected SnmpStandardObjectServer objectserver;
    protected JvmMemMgrPoolRelTableMeta tableJvmMemMgrPoolRelTable;
    protected JvmMemPoolTableMeta tableJvmMemPoolTable;
    protected JvmMemGCTableMeta tableJvmMemGCTable;
    protected JvmMemManagerTableMeta tableJvmMemManagerTable;
    
    public JvmMemoryMeta(SnmpMib snmpMib, SnmpStandardObjectServer objectserver) {
        this.objectserver = null;
        this.tableJvmMemMgrPoolRelTable = null;
        this.tableJvmMemPoolTable = null;
        this.tableJvmMemGCTable = null;
        this.tableJvmMemManagerTable = null;
        this.objectserver = objectserver;
        try {
            this.registerObject(120L);
            this.registerObject(23L);
            this.registerObject(22L);
            this.registerObject(21L);
            this.registerObject(110L);
            this.registerObject(20L);
            this.registerObject(13L);
            this.registerObject(12L);
            this.registerObject(3L);
            this.registerObject(11L);
            this.registerObject(2L);
            this.registerObject(101L);
            this.registerObject(10L);
            this.registerObject(1L);
            this.registerObject(100L);
        }
        catch (IllegalAccessException ex) {
            throw new RuntimeException(ex.getMessage());
        }
    }
    
    public SnmpValue get(long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 120: {
                throw new SnmpStatusException(224);
            }
            case 23: {
                return new SnmpCounter64(this.node.getJvmMemoryNonHeapMaxSize());
            }
            case 22: {
                return new SnmpCounter64(this.node.getJvmMemoryNonHeapCommitted());
            }
            case 21: {
                return new SnmpCounter64(this.node.getJvmMemoryNonHeapUsed());
            }
            case 110: {
                throw new SnmpStatusException(224);
            }
            case 20: {
                return new SnmpCounter64(this.node.getJvmMemoryNonHeapInitSize());
            }
            case 13: {
                return new SnmpCounter64(this.node.getJvmMemoryHeapMaxSize());
            }
            case 12: {
                return new SnmpCounter64(this.node.getJvmMemoryHeapCommitted());
            }
            case 3: {
                return new SnmpInt(this.node.getJvmMemoryGCCall());
            }
            case 11: {
                return new SnmpCounter64(this.node.getJvmMemoryHeapUsed());
            }
            case 2: {
                return new SnmpInt(this.node.getJvmMemoryGCVerboseLevel());
            }
            case 101: {
                throw new SnmpStatusException(224);
            }
            case 10: {
                return new SnmpCounter64(this.node.getJvmMemoryHeapInitSize());
            }
            case 1: {
                return new SnmpGauge(this.node.getJvmMemoryPendingFinalCount());
            }
            case 100: {
                throw new SnmpStatusException(224);
            }
            default: {
                throw new SnmpStatusException(225);
            }
        }
    }
    
    public SnmpValue set(SnmpValue snmpValue, long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 120: {
                throw new SnmpStatusException(17);
            }
            case 23: {
                throw new SnmpStatusException(17);
            }
            case 22: {
                throw new SnmpStatusException(17);
            }
            case 21: {
                throw new SnmpStatusException(17);
            }
            case 110: {
                throw new SnmpStatusException(17);
            }
            case 20: {
                throw new SnmpStatusException(17);
            }
            case 13: {
                throw new SnmpStatusException(17);
            }
            case 12: {
                throw new SnmpStatusException(17);
            }
            case 3: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.setJvmMemoryGCCall(new EnumJvmMemoryGCCall(((SnmpInt)snmpValue).toInteger()));
                    }
                    catch (IllegalArgumentException ex) {
                        throw new SnmpStatusException(10);
                    }
                    return new SnmpInt(this.node.getJvmMemoryGCCall());
                }
                throw new SnmpStatusException(7);
            }
            case 11: {
                throw new SnmpStatusException(17);
            }
            case 2: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.setJvmMemoryGCVerboseLevel(new EnumJvmMemoryGCVerboseLevel(((SnmpInt)snmpValue).toInteger()));
                    }
                    catch (IllegalArgumentException ex2) {
                        throw new SnmpStatusException(10);
                    }
                    return new SnmpInt(this.node.getJvmMemoryGCVerboseLevel());
                }
                throw new SnmpStatusException(7);
            }
            case 101: {
                throw new SnmpStatusException(17);
            }
            case 10: {
                throw new SnmpStatusException(17);
            }
            case 1: {
                throw new SnmpStatusException(17);
            }
            case 100: {
                throw new SnmpStatusException(17);
            }
            default: {
                throw new SnmpStatusException(17);
            }
        }
    }
    
    public void check(SnmpValue snmpValue, long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 120: {
                throw new SnmpStatusException(17);
            }
            case 23: {
                throw new SnmpStatusException(17);
            }
            case 22: {
                throw new SnmpStatusException(17);
            }
            case 21: {
                throw new SnmpStatusException(17);
            }
            case 110: {
                throw new SnmpStatusException(17);
            }
            case 20: {
                throw new SnmpStatusException(17);
            }
            case 13: {
                throw new SnmpStatusException(17);
            }
            case 12: {
                throw new SnmpStatusException(17);
            }
            case 3: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.checkJvmMemoryGCCall(new EnumJvmMemoryGCCall(((SnmpInt)snmpValue).toInteger()));
                        break;
                    }
                    catch (IllegalArgumentException ex) {
                        throw new SnmpStatusException(10);
                    }
                }
                else {
                    throw new SnmpStatusException(7);
                }
            }
            case 11: {
                throw new SnmpStatusException(17);
            }
            case 2: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.checkJvmMemoryGCVerboseLevel(new EnumJvmMemoryGCVerboseLevel(((SnmpInt)snmpValue).toInteger()));
                        break;
                    }
                    catch (IllegalArgumentException ex2) {
                        throw new SnmpStatusException(10);
                    }
                }
                else {
                    throw new SnmpStatusException(7);
                }
            }
            case 101: {
                throw new SnmpStatusException(17);
            }
            case 10: {
                throw new SnmpStatusException(17);
            }
            case 1: {
                throw new SnmpStatusException(17);
            }
            case 100: {
                throw new SnmpStatusException(17);
            }
            default: {
                throw new SnmpStatusException(17);
            }
        }
    }
    
    protected void setInstance(JvmMemoryMBean node) {
        this.node = node;
    }
    
    public void get(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.get(this, snmpMibSubRequest, n);
    }
    
    public void set(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.set(this, snmpMibSubRequest, n);
    }
    
    public void check(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.check(this, snmpMibSubRequest, n);
    }
    
    public boolean isVariable(long n) {
        switch ((int)n) {
            case 1:
            case 2:
            case 3:
            case 10:
            case 11:
            case 12:
            case 13:
            case 20:
            case 21:
            case 22:
            case 23: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public boolean isReadable(long n) {
        switch ((int)n) {
            case 1:
            case 2:
            case 3:
            case 10:
            case 11:
            case 12:
            case 13:
            case 20:
            case 21:
            case 22:
            case 23: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public boolean skipVariable(long n, Object o, int n2) {
        switch ((int)n) {
            case 10:
            case 11:
            case 12:
            case 13:
            case 20:
            case 21:
            case 22:
            case 23: {
                if (n2 == 0) {
                    return true;
                }
                break;
            }
        }
        return super.skipVariable(n, o, n2);
    }
    
    public String getAttributeName(long n) throws SnmpStatusException {
        switch ((int)n) {
            case 120: {
                throw new SnmpStatusException(224);
            }
            case 23: {
                return "JvmMemoryNonHeapMaxSize";
            }
            case 22: {
                return "JvmMemoryNonHeapCommitted";
            }
            case 21: {
                return "JvmMemoryNonHeapUsed";
            }
            case 110: {
                throw new SnmpStatusException(224);
            }
            case 20: {
                return "JvmMemoryNonHeapInitSize";
            }
            case 13: {
                return "JvmMemoryHeapMaxSize";
            }
            case 12: {
                return "JvmMemoryHeapCommitted";
            }
            case 3: {
                return "JvmMemoryGCCall";
            }
            case 11: {
                return "JvmMemoryHeapUsed";
            }
            case 2: {
                return "JvmMemoryGCVerboseLevel";
            }
            case 101: {
                throw new SnmpStatusException(224);
            }
            case 10: {
                return "JvmMemoryHeapInitSize";
            }
            case 1: {
                return "JvmMemoryPendingFinalCount";
            }
            case 100: {
                throw new SnmpStatusException(224);
            }
            default: {
                throw new SnmpStatusException(225);
            }
        }
    }
    
    public boolean isTable(long n) {
        switch ((int)n) {
            case 120: {
                return true;
            }
            case 110: {
                return true;
            }
            case 101: {
                return true;
            }
            case 100: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public SnmpMibTable getTable(long n) {
        switch ((int)n) {
            case 120: {
                return this.tableJvmMemMgrPoolRelTable;
            }
            case 110: {
                return this.tableJvmMemPoolTable;
            }
            case 101: {
                return this.tableJvmMemGCTable;
            }
            case 100: {
                return this.tableJvmMemManagerTable;
            }
            default: {
                return null;
            }
        }
    }
    
    public void registerTableNodes(SnmpMib snmpMib, MBeanServer mBeanServer) {
        this.tableJvmMemMgrPoolRelTable = this.createJvmMemMgrPoolRelTableMetaNode("JvmMemMgrPoolRelTable", "JvmMemory", snmpMib, mBeanServer);
        if (this.tableJvmMemMgrPoolRelTable != null) {
            this.tableJvmMemMgrPoolRelTable.registerEntryNode(snmpMib, mBeanServer);
            snmpMib.registerTableMeta("JvmMemMgrPoolRelTable", this.tableJvmMemMgrPoolRelTable);
        }
        this.tableJvmMemPoolTable = this.createJvmMemPoolTableMetaNode("JvmMemPoolTable", "JvmMemory", snmpMib, mBeanServer);
        if (this.tableJvmMemPoolTable != null) {
            this.tableJvmMemPoolTable.registerEntryNode(snmpMib, mBeanServer);
            snmpMib.registerTableMeta("JvmMemPoolTable", this.tableJvmMemPoolTable);
        }
        this.tableJvmMemGCTable = this.createJvmMemGCTableMetaNode("JvmMemGCTable", "JvmMemory", snmpMib, mBeanServer);
        if (this.tableJvmMemGCTable != null) {
            this.tableJvmMemGCTable.registerEntryNode(snmpMib, mBeanServer);
            snmpMib.registerTableMeta("JvmMemGCTable", this.tableJvmMemGCTable);
        }
        this.tableJvmMemManagerTable = this.createJvmMemManagerTableMetaNode("JvmMemManagerTable", "JvmMemory", snmpMib, mBeanServer);
        if (this.tableJvmMemManagerTable != null) {
            this.tableJvmMemManagerTable.registerEntryNode(snmpMib, mBeanServer);
            snmpMib.registerTableMeta("JvmMemManagerTable", this.tableJvmMemManagerTable);
        }
    }
    
    protected JvmMemMgrPoolRelTableMeta createJvmMemMgrPoolRelTableMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmMemMgrPoolRelTableMeta(snmpMib, this.objectserver);
    }
    
    protected JvmMemPoolTableMeta createJvmMemPoolTableMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmMemPoolTableMeta(snmpMib, this.objectserver);
    }
    
    protected JvmMemGCTableMeta createJvmMemGCTableMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmMemGCTableMeta(snmpMib, this.objectserver);
    }
    
    protected JvmMemManagerTableMeta createJvmMemManagerTableMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmMemManagerTableMeta(snmpMib, this.objectserver);
    }
}
